@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 
     Author: Ettore Perazzoli <ettore@helixcode.com>
 */
@@ -29,6 +29,7 @@
 #include "gtkhtml.h"
 #include "control-data.h"
 
-GtkWidget *toolbar_style         (GtkHTMLControlData *cd);
-void       toolbar_update_format (GtkHTMLControlData *cd);
+GtkWidget *toolbar_style          (GtkHTMLControlData *cd);
+void       toolbar_update_format  (GtkHTMLControlData *cd);
+void       toolbar_apply_color    (GtkHTMLControlData *cd);
 #endif /* _TOOLBAR_H */
